@@ -12,4 +12,4 @@ class t5chem(object):
         """将反应转化为 t5chem 的 product 预测任务"""
         products = [rxn.product for rxn in rxns]
         reactants = [rxn.reactant for rxn in rxns]
-        return DataFrame({'products': products, 'reactants': reactants})
+        return DataFrame({"products": products, "reactants": reactants})
