@@ -4,10 +4,9 @@ from typing import List
 
 
 class Metrics(object):
-
     @staticmethod
     def remap(x: np.array, x_min, x_max):
-        assert x_max > x_min, '最大最小值一样'
+        assert x_max > x_min, "最大最小值一样"
         return (x - x_min) / (x_max - x_min)
 
     @staticmethod
