@@ -1,6 +1,8 @@
 from abc import ABC, abstractmethod
 from typing import Optional, Iterable
-from rdkit import Chem
+from rdkit import Chem, RDLogger
+
+RDLogger.DisableLog("rdApp.*")
 
 
 def canonize_smi(smi: str):
@@ -10,15 +12,17 @@ def canonize_smi(smi: str):
         return None
 
 
-def canonize_rxn(rxn: str):
+def canonize_rxn(rxn: str) -> Optional[str]:
     """标准化反应"""
     try:
-        new_rxn = rxn.split('>>')
+        new_rxn = rxn.split(">>")
+        if len(new_rxn) != 2:
+            return None
         r = new_rxn[0]
         p = new_rxn[1]
-        new_r = '.'.join([canonize_smi(x) for x in r.split('.')])
+        new_r = ".".join([canonize_smi(x) for x in r.split(".")])
         new_p = canonize_smi(p)
-        return new_r + '>>' + new_p
+        return new_r + ">>" + new_p
     except:
         return None
 
@@ -40,7 +44,9 @@ class SMI(object):
 
 
 class RXN(object):
-    def __init__(self, rxn_str: str, yield_: Optional[float] = None, canonize: bool = True):
+    def __init__(
+        self, rxn_str: str, yield_: Optional[float] = None, canonize: bool = True
+    ):
         if canonize:
             self.rxn_str = canonize_rxn(rxn_str)
         else:
@@ -50,11 +56,11 @@ class RXN(object):
 
     @property
     def products(self):
-        return self.rxn_str.split('>>')[1].split('.')
+        return self.rxn_str.split(">>")[1].split(".")
 
     @property
     def reactants(self):
-        return self.rxn_str.split('>>')[0].split('.')
+        return self.rxn_str.split(">>")[0].split(".")
 
     def __str__(self):
         return repr(self)
